@@ -23,7 +23,7 @@ Usage::
     list_archive_rules_paginator: ListArchiveRulesPaginator = client.get_paginator("list_archive_rules")
     list_findings_paginator: ListFindingsPaginator = client.get_paginator("list_findings")
 """
-from mypy_boto3_accessanalyzer.client import AccessAnalyzerClient as Client, AccessAnalyzerClient
+from mypy_boto3_accessanalyzer.client import AccessAnalyzerClient, AccessAnalyzerClient as Client
 from mypy_boto3_accessanalyzer.paginator import (
     ListAnalyzedResourcesPaginator,
     ListAnalyzersPaginator,
